﻿module xors3d;

alias int Entity;
alias int PSystem;
alias int Font;
alias int Surface;
alias int PostEffect;
alias int VertexShader;
alias int PixelShader;
alias int Texture;
alias int Image;
alias int Brush;
alias int Buffer;
alias int Sound;
alias int Channel;
alias int Effect;
alias int Group;
alias int Camera;

const int NULL = 0;
const int LOG_NO = 5;
const int LOG_FATAL = 4;
const int LOG_ERROR = 3;
const int LOG_WARNING = 2;
const int LOG_MESSAGE = 1;
const int LOG_INFO = 0;
const int LOG_HTML = 1;
const int LOG_COUT = 2;
const int LOG_HTML_COUT = 3;
const int LOG_STRING = 4;
const int LOG_HTML_STRING = 5;
const int LOG_COUT_STRING = 6;
const int LOG_HTML_COUT_STRING = 7;
const int SKIN_HARDWARE = 0;
const int SKIN_HARDWAREVS = 1;
const int SKIN_SOFTWARE = 2;
const int LIGHT_DIRECTIONAL = 1;
const int LIGHT_POINT = 2;
const int LIGHT_SPOT = 3;
const int TF_NONE = 0;
const int TF_POINT = 1;
const int TF_LINEAR = 2;
const int TF_ANISOTROPIC = 3;
const int TF_ANISOTROPICX4 = 4;
const int TF_ANISOTROPICX8 = 5;
const int TF_ANISOTROPICX16 = 6;
const int PS_1_1 = 0;
const int PS_1_2 = 1;
const int PS_1_3 = 2;
const int PS_1_4 = 3;
const int PS_2_0 = 4;
const int PS_3_0 = 5;
const int VS_1_1 = 0;
const int VS_2_0 = 1;
const int VS_3_0 = 2;
const int WORLD = 0;
const int WORLDVIEWPROJ = 1;
const int VIEWPROJ = 2;
const int VIEW = 3;
const int PROJ = 4;
const int WORLDVIEW = 5;
const int VIEWINVERSE = 6;
const int ADDITIONAL1 = 7;
const int ADDITIONAL2 = 8;
const int ADDITIONAL3 = 9;
const int ADDITIONAL4 = 10;
const int ADDITIONAL5 = 11;
const int ADDITIONAL6 = 12;
const int ADDITIONAL7 = 13;
const int ADDITIONAL8 = 14;
const int WORLDINVERSETRANSPOSE = 15;
const int WORLDINVERSE = 16;
const int WORLDTRANSPOSE = 17;
const int VIEWPROJINVERSE = 18;
const int VIEWPROJINVERSETRANSPOSE = 19;
const int VIEWTRANSPOSE = 20;
const int VIEWINVRSETRANSPOSE = 21;
const int PROJINVERSE = 22;
const int PROJTRANSPOSE = 23;
const int PROJINVRSETRANSPOSE = 24;
const int WORLDVIEWPROJTRANSPOSE = 25;
const int WORLDVIEWPROJINVERSE = 26;
const int WORLDVIEWPROJINVERSETRANSPOSE = 27;
const int WORLDVIEWTRANSPOSE = 28;
const int WORLDVIEWINVERSE = 29;
const int WORLDVIEWINVERSETRANSPOSE = 30;
const int AANONE = 0;
const int AA2SAMPLES = 1;
const int AA3SAMPLES = 2;
const int AA4SAMPLES = 3;
const int AA5SAMPLES = 4;
const int AA6SAMPLES = 5;
const int AA7SAMPLES = 6;
const int AA8SAMPLES = 7;
const int AA9SAMPLES = 8;
const int AA10SAMPLES = 9;
const int AA11SAMPLES = 10;
const int AA12SAMPLES = 11;
const int AA13SAMPLES = 12;
const int AA14SAMPLES = 13;
const int AA15SAMPLES = 14;
const int AA16SAMPLES = 15;
const int MOUSE_LEFT = 0;
const int MOUSE_RIGHT = 1;
const int MOUSE_MIDDLE = 2;
const int MOUSE4 = 3;
const int MOUSE5 = 4;
const int MOUSE6 = 5;
const int MOUSE7 = 6;
const int MOUSE8 = 7;
const int KEY_ESCAPE = 1;
const int KEY_1 = 2;
const int KEY_2 = 3;
const int KEY_3 = 4;
const int KEY_4 = 5;
const int KEY_5 = 6;
const int KEY_6 = 7;
const int KEY_7 = 8;
const int KEY_8 = 9;
const int KEY_9 = 10;
const int KEY_0 = 11;
const int KEY_MINUS = 12;
const int KEY_EQUALS = 13;
const int KEY_BACK = 14;
const int KEY_TAB = 15;
const int KEY_Q = 16;
const int KEY_W = 17;
const int KEY_E = 18;
const int KEY_R = 19;
const int KEY_T = 20;
const int KEY_Y = 21;
const int KEY_U = 22;
const int KEY_I = 23;
const int KEY_O = 24;
const int KEY_P = 25;
const int KEY_LBRACKET = 26;
const int KEY_RBRACKET = 27;
const int KEY_RETURN = 28;
const int KEY_LCONTROL = 29;
const int KEY_RCONTROL = 157;
const int KEY_A = 30;
const int KEY_S = 31;
const int KEY_D = 32;
const int KEY_F = 33;
const int KEY_G = 34;
const int KEY_H = 35;
const int KEY_J = 36;
const int KEY_K = 37;
const int KEY_L = 38;
const int KEY_SEMICOLON = 39;
const int KEY_APOSTROPHE = 40;
const int KEY_GRAVE = 41;
const int KEY_LSHIFT = 42;
const int KEY_BACKSLASH = 43;
const int KEY_Z = 44;
const int KEY_X = 45;
const int KEY_C = 46;
const int KEY_V = 47;
const int KEY_B = 48;
const int KEY_N = 49;
const int KEY_M = 50;
const int KEY_COMMA = 51;
const int KEY_PERIOD = 52;
const int KEY_SLASH = 53;
const int KEY_RSHIFT = 54;
const int KEY_MULTIPLY = 55;
const int KEY_MENU = 56;
const int KEY_SPACE = 57;
const int KEY_F1 = 59;
const int KEY_F2 = 60;
const int KEY_F3 = 61;
const int KEY_F4 = 62;
const int KEY_F5 = 63;
const int KEY_F6 = 64;
const int KEY_F7 = 65;
const int KEY_F8 = 66;
const int KEY_F9 = 67;
const int KEY_F10 = 68;
const int KEY_NUMLOCK = 69;
const int KEY_SCROLL = 70;
const int KEY_NUMPAD7 = 71;
const int KEY_NUMPAD8 = 72;
const int KEY_NUMPAD9 = 73;
const int KEY_SUBTRACT = 74;
const int KEY_NUMPAD4 = 75;
const int KEY_NUMPAD5 = 76;
const int KEY_NUMPAD6 = 77;
const int KEY_ADD = 78;
const int KEY_NUMPAD1 = 79;
const int KEY_NUMPAD2 = 80;
const int KEY_NUMPAD3 = 81;
const int KEY_NUMPAD0 = 82;
const int KEY_DECIMAL = 83;
const int KEY_TILD = 86;
const int KEY_F11 = 87;
const int KEY_F12 = 88;
const int KEY_NUMPADENTER = 156;
const int KEY_RMENU = 221;
const int KEY_PAUSE = 197;
const int KEY_HOME = 199;
const int KEY_UP = 200;
const int KEY_PRIOR = 201;
const int KEY_LEFT = 203;
const int KEY_RIGHT = 205;
const int KEY_END = 207;
const int KEY_DOWN = 208;
const int KEY_NEXT = 209;
const int KEY_INSERT = 210;
const int KEY_DELETE = 211;
const int KEY_LWIN = 219;
const int KEY_RWIN = 220;
const int KEY_BACKSPACE = KEY_BACK;
const int KEY_NUMPADSTAR = KEY_MULTIPLY;
const int KEY_LALT = 184;
const int KEY_CAPSLOCK = 58;
const int KEY_NUMPADMINUS = KEY_SUBTRACT;
const int KEY_NUMPADPLUS = KEY_ADD;
const int KEY_NUMPADPERIOD = KEY_DECIMAL;
const int KEY_DIVIDE = 181;
const int KEY_NUMPADSLASH = KEY_DIVIDE;
const int KEY_RALT = 56;
const int KEY_UPARROW = KEY_UP;
const int KEY_PGUP = KEY_PRIOR;
const int KEY_LEFTARROW = KEY_LEFT;
const int KEY_RIGHTARROW = KEY_RIGHT;
const int KEY_DOWNARROW = KEY_DOWN;
const int KEY_PGDN = KEY_NEXT;
const int FOG_NONE = 0;
const int FOG_LINEAR = 1;
const int PROJ_DISABLE = 0;
const int PROJ_PERSPECTIVE = 1;
const int PROJ_ORTHOGRAPHIC = 2;
const int FX_NOTHING = 0;
const int FX_FULLBRIGHT = 1;
const int FX_VERTEXCOLOR = 2;
const int FX_FLATSHEDED = 4;
const int FX_DISABLEFOG = 8;
const int FX_DISABLECULLING = 16;
const int BLEND_ALPHA = 1;
const int BLEND_MULTIPLY = 2;
const int BLEND_ADD = 3;
const int CMP_NEVER = 1;
const int CMP_LESS = 2;
const int CMP_EQUAL = 3;
const int CMP_LESSEQUAL = 4;
const int CMP_GREATER = 5;
const int CMP_NOTEQUAL = 6;
const int CMP_GREATEREQUAL = 7;
const int CMP_ALWAYS = 8;
const int AXIS_X = 1;
const int AXIS_Y = 2;
const int AXIS_Z = 3;
const int FLAGS_COLOR = 1;
const int FLAGS_ALPHA = 2;
const int FLAGS_MASKED = 4;
const int FLAGS_MIPMAPPED = 8;
const int FLAGS_CLAMPU = 16;
const int FLAGS_CLAMPV = 32;
const int FLAGS_SPHERICALENVMAP = 64;
const int FLAGS_CUBICENVMAP = 128;
const int FLAGS_R32F = 256;
const int FLAGS_RESERVED = 512;
const int FLAGS_VOLUMETEXTURE = 1024;
const int FLAGS_ARBG16F = 2048;
const int FLAGS_ARBG32F = 4096;
const int TEXBLEND_NONE = 0;
const int TEXBLEND_ALPHA = 1;
const int TEXBLEND_MULTIPLY = 2;
const int TEXBLEND_ADD = 3;
const int TEXBLEND_DOT3 = 4;
const int TEXBLEND_LIGHTMAP = 5;
const int TEXBLEND_SEPARATEALPHA = 6;
const int FACE_LEFT = 0;
const int FACE_FORWARD = 1;
const int FACE_RIGHT = 2;
const int FACE_BACKWARD = 3;
const int FACE_UP = 4;
const int FACE_DOWN = 5;
const int ANIMATION_STOP = 0;
const int ANIMATION_LOOP = 1;
const int ANIMATION_PINGPONG = 2;
const int ANIMATION_ONE = 3;
const int SPHERETOSHPHERE = 1;
const int SPHERETOBOX = 2;
const int SPHERETOTRIMESH = 3;
const int RESPONSE_STOP = 1;
const int RESPONSE_SLIDING = 2;
const int RESPONSE_SLIDING_DOWNLOCK = 3;
const int PICK_NONE = 0;
const int PICK_SPHERE = 1;
const int PICK_TRIMESH = 2;
const int PICK_BOX = 3;
const int SPRITE_FIXED = 1;
const int SPRITE_FREE = 2;
const int SPRITE_FREEROLL = 3;
const int SPRITE_FIXEDYAW = 4;
const int DEFERRED_NONE = 0;
const int DEFERRED_ARGB8 = 1;
const int DEFERRED_R32F = 2;
const int DEFERRED_ARGB32F = 3;
const int DEFERRED_GR16F = 4;
const int DEFERRED_RGB10A2 = 5;
const int OPTIMIZE_VERTEXCACHE = 1;
const int OPTIMIZE_STRIPREORDER = 2;
const int OPTIMIZE_ATTRSORT = 3;
const int JOY_NONE = 0;
const int JOY_DIGITAL = 1;
const int JOY_ANALOG = 2;

extern(Windows)
{
	void xTextureFilter(char* matchText, int flags);

	void xClearTextureFilters();

	int xDIPCounter();

	int xSurfRendered();

	int xEntityRendered();

	bool xEntityVisible(Entity entity);

	void xRenderShadows(Entity camera, Texture texture);

	void xLightShadowEpsilons(Entity light, float eps1, float eps2 = 0.16f);

	void xSetShadowShader(char* path);

	void xInitShadows(int dirSize = 512, int spotSize = 512,
			int pointSize = 128);

	void xSetShadowParams(int splitPlanes = 4, float splitLambda = 0.95f,
			bool useOrtho = true, float lightDist = 500.0f);

	void xEntityCastShadows(Entity entity, Entity light, bool state);

	bool xEntityIsCaster(Entity entity, Entity light);

	void xShadowPriority(int prior);

	void xLightEnableShadows(Entity light, int prior);

	bool xLightShadowsEnabled(Entity light);

	void xInitDeferred(int tex1 = DEFERRED_ARGB8, int tex2 = DEFERRED_ARGB8,
			int tex3 = DEFERRED_R32F, int tex4 = DEFERRED_NONE);

	void xSetDeferredShaders(char* mrtShader, char* lightShader);

	void xRenderWorldDeferred(Texture texture = NULL);

	void xClearLogString();

	char* xGetLogString();

	void xSetLogLevel(int level = LOG_WARNING);

	void xSetLogTarget(int target = LOG_HTML);

	int xGetLogLevel();

	int xGetLogTarget();

	int xCreateLog(int target = LOG_WARNING, int level = LOG_HTML,
			char* filename = "xors_log.html");

	int xJoyType(int portID = 0);

	int xJoyDown(int key, int portID = 0);

	int xJoyHit(int key, int portID = 0);

	int xGetJoy(int portID = 0);

	int xWaitJoy(int portID = 0);

	float xJoyX(int portID = 0);

	float xJoyY(int portID = 0);

	float xJoyZ(int portID = 0);

	float xJoyU(int portID = 0);

	float xJoyV(int portID = 0);

	float xJoyPitch(int portID = 0);

	float xJoyYaw(int portID = 0);

	float xJoyRoll(int portID = 0);

	float xJoyHat(int portID = 0);

	int xJoyXDir(int portID = 0);

	int xJoyYDir(int portID = 0);

	int xJoyZDir(int portID = 0);

	int xJoyUDir(int portID = 0);

	int xJoyVDir(int portID = 0);

	void xFlushJoy();

	void* xGetFunctionAddress(char* name);

	Texture xLoadTextureInThread(char* path,
			int flags = FLAGS_COLOR | FLAGS_MIPMAPPED);

	bool xTextureLoaded(Texture texture);

	int xGetNumberRT();

	void xSetMRT(Texture buffTex, int frame, int index);

	void xUnSetMRT();

	float xEntityScaleX(Entity entity);

	float xEntityScaleY(Entity entity);

	float xEntityScaleZ(Entity entity);

	void* xLoadTextureInRAM(char* path);

	Texture xCreateTextureFromRAM(void* tRAM);

	Group xCreateGroup();

	void xGroupAddEntity(Group group, Entity entity);

	void xRenderGroup(Group group);

	void xGroupRemoveEntity(Group group, Entity entity);

	void xAddMesh(Entity src, Entity dest);

	int xAddTriangle(Surface surf, int v0, int v1, int v2);

	void xAmbientLight(int red, int green, int blue);

	void xAntiAlias(bool state);

	void xAppTitle(char* title);

	void xAutoMidHandle(bool state);

	Buffer xBackBuffer();

	void xBufferDelete(Buffer buff);

	void* xBufferMatrixGetElement(Buffer buff, int index);

	void xBufferMatrixSetElement(Buffer buff, int index, void* matrix);

	float xBufferVectorsGetElement(Buffer buff, int index, int element);

	void xBufferVectorsSetElement(Buffer buff, int index, float x, float y,
			float z, float w);

	void xCameraClipPlane(Entity camera, int index, bool enabled, float a,
			float b, float c, float d);

	void xCameraClsColor(Entity camera, float red, float green, float blue);

	void xCameraClsMode(Entity camera, bool clearColor = true,
			bool clearZBbuffer = true);

	void xCameraFogColor(Entity camera, float red, float green, float blue);

	void xCameraFogRange(Entity camera, float nearRange, float farRange);

	Entity xCameraPick(Entity camera, float x, float y);

	void xCameraProject(Entity camera, float x, float y, float z);

	void xCameraRange(Entity camera, float nearPlane, float farPlane);

	void xCameraViewport(Entity camera, int x, int y, int width, int height);

	void xCameraZoom(Entity camera, float zoom = 1.0f);

	void xChannelPan(Channel channel, float pan);

	void xChannelPitch(Channel channel, int hertz);

	bool xChannelPlaying(Channel channel);

	void xChannelVolume(Channel channel, float volume);

	void xClearEffectConstants(Entity entity);

	void xClearSurfaceConstants(Surface surface);

	void xClearPixelShaderConstants(Entity entity);

	void xClearVertexShaderConstants(Entity entity);

	void xCls();

	void xClsColor(int red, int green, int blue, int alpha);

	Entity xCollisionEntity(Entity entity, int index);

	float xCollisionNX(Entity entity, int index);

	float xCollisionNY(Entity entity, int index);

	float xCollisionNZ(Entity entity, int index);

	Surface xCollisionSurface(Entity entity, int index);

	int xCollisionTime(Entity entity, int index);

	float xCollisionX(Entity entity, int index);

	float xCollisionY(Entity entity, int index);

	float xCollisionZ(Entity entity, int index);

	void xCollisions(int srcType, int destType, int method = SPHERETOSHPHERE,
			int response = RESPONSE_STOP);

	int xCollisionTriangle(Entity entity, int index);

	void xColor(int red, int green, int blue);

	int xColorBlue();

	int xColorGreen();

	int xColorRed();

	void xCopyRect(int sx, int sy, int swidth, int sheight, int dx, int dy,
			Buffer srcBuff = -1, Buffer destBuff = -1);

	int xCountChildren(Entity entity);

	int xCountCollisions(Entity entity);

	int xCountSurfaces(Entity entity);

	int xCountTriangles(Surface surface);

	int xCountVertices(Surface surface);

	int xCPUFamily();

	int xCPUModel();

	char* xCPUName();

	int xCPUSpeed();

	int xCPUStepping();

	char* xCPUVendor();

	Entity xCreate3DLine(Entity parent = NULL);

	void x3DLinePoints(Entity line, float x0, float y0, float z0, float x1,
			float y1, float z1);

	void* xCreateBufferMatrix(int index);

	void* xCreateBufferVectors(int index);

	void xCreateDSS(int width, int height);

	Entity xCreatePoly(bool sides, Entity parent = NULL);

	Entity xCreatePostEffectPoly(Entity camera, int mode = 1);

	void xDeleteDSS();

	void xDeleteEffectConstant(Entity entity, char* name);

	void xDeleteSurfaceConstant(Surface surface, char* name);

	void xDeleteMeshIB(Entity entity);

	void xDeleteMeshVB(Entity entity);

	void xDeletePixelShaderConstant(Entity entity, char* name);

	void xDeleteVertexShaderConstant(Entity entity, char* name);

	float xDeltaPitch(Entity entity1, Entity entity2);

	float xDeltaYaw(Entity entity1, Entity entity2);

	void xDither(bool state);

	void xDrawBBox(bool state, bool zenable, int red, int green, int blue,
			int alpha);

	Channel xEmitSound(Sound sound, Entity entity);

	void xEnableEntityShader(Entity entity, bool enable);

	void xEnablePostProcessing(bool state);

	void xEntityAlpha(Entity entity, float alpha);

	void xEntityAmbientColor(Entity entity, float red, float green, float blue);

	void xEntityAutoFade(Entity entity, float nearRange, float farRange);

	void xEntityBlend(Entity entity, int mode = BLEND_ALPHA);

	void xEntityBox(Entity entity, float x, float y, float z, float width,
			float height, float depth);

	char* xEntityClass(Entity entity);

	void xEntityColor(Entity entity, float red, float green, float blue);

	float xEntityDistance(Entity entity1, Entity entity2);

	void xEntityEmissiveColor(Entity entity, float red, float green, float blue);

	void xEntityFX(Entity entity, int fxFlags = FX_NOTHING);

	bool xEntityInView(Entity entity, Entity camera);

	char* xEntityName(Entity entity);

	void xEntityOrder(Entity entity, int order = 0);

	int xEntityPick(Entity entity, float range);

	void xEntityRadius(Entity entity, float radius);

	bool xEntityShader(Entity entity);

	void xEntitySpecularColor(Entity entity, float red, float green, float blue);

	void xEntityType(Entity entity, int cType, bool recurse = false);

	Entity xFindChild(Entity entity, char* name);

	Surface xFindSurface(Entity entity, Brush brush);

	void xFlip();

	void xFlipMesh(Entity entity);

	int xFontHeight();

	int xFontWidth();

	void xFreeBrush(Brush brush);

	void xFreeEffect(Effect effect);

	void xFreeEntity(Entity entity);

	void xFreeFont(Font font);

	void xFreeImage(Image image);

	void xFreePostEffect(PostEffect effect);

	void xFreeSound(Sound sound);

	void xFreeTexture(Texture texture);

	int xGetAlphaFunc(Entity entity);

	int xGetAlphaRef(Entity entity);

	float xGetAvailPageMem();

	float xGetAvailPhysMem();

	float xGetAvailVidLocalMem();

	float xGetAvailVidMem();

	float xGetAvailVidNonlocalMem();

	Entity xGetChild(Entity entity, int index);

	int xGetColor(int x, int y);

	void* xGetDevice();

	float xGetEntityAlpha(Entity entity);

	Brush xGetEntityBrush(Entity entity);

	void* xGetEntityMatrix(Entity entity);

	float xGetEntityMatrixElement(Entity entity, int row, int cell);

	int xGetEntityType(Entity entity);

	int xGetFPS();

	int xGetKey();

	float xGetMatElement(Entity entity, int row, int cell);

	int xGetMaxAntiAlias();

	int xGetMaxPixelShaderVersion();

	int xGetMaxVertexShaderVersion();

	int* xGetMeshIB(Entity entity);

	int xGetMeshIBSize(Entity entity);

	float* xGetMeshVB(Entity entity);

	int xGetMeshVBSize(Entity entity);

	Entity xGetParent(Entity entity);

	void* xGetRenderWindow();

	Surface xGetSurface(Entity entity, int index);

	Brush xGetSurfaceBrush(Surface surface);

	Texture xGetSurfaceTexture(Surface surface, int index);

	int xGetTextureFrames(Texture texture);

	void* xGetTextureSurface(Texture texture, int frame = 0);

	float xGetTotalPageMem();

	float xGetTotalPhysMem();

	float xGetTotalVidLocalMem();

	float xGetTotalVidMem();

	float xGetTotalVidNonlocalMem();

	void* xGetProjectionMatrix(Entity camera);

	void* xGetViewMatrix(Entity camera);

	Buffer xGraphicsBuffer();

	int xGraphicsDepth();

	int xGraphicsHeight();

	int xGraphicsWidth();

	void xHandleImage(Image image, int x, int y);

	void xHandleSprite(Entity entity, float x, float y);

	void xHideEntity(Entity entity);

	void xHidePointer();

	int xImageHeight(Image image);

	bool xImageRectCollide(Image image, int x, int y, int frame, int rectx,
			int recty, int rectWidth, int rectHeight);

	bool xImageRectOverlap(Image image, int x, int y, int rectx, int recty,
			int rectWidth, int rectHeight);

	int xImageWidth(Image image);

	int xImageXHandle(Image image);

	int xImageYHandle(Image image);

	bool xImagesCollide(Image image1, int x1, int y1, int frame1, Image image2,
			int x2, int y2, int frame2);

	bool xImagesOverlap(Image image1, int x1, int y1, Image image2, int x2,
			int y2);

	void xKey(char* key);

	int xKeyDown(int key);

	void xFlushKeys();

	int xKeyHit(int key);

	int xKeyUp(int key);

	void xLightColor(Entity light, float red, float green, float blue);

	void xLightConeAngles(Entity light, float inner, float outer);

	void xLightRange(Entity light, float range);

	void xLine(int x1, int y1, int x2, int y2);

	void xLine3D(int x1, int y1, int z1, int x2, int y2, int z2, int red,
			int green, int blue, int alpha, bool zenable = true);

	Sound xLoad3DSound(char* path);

	Image xLoadAnimImage(char* path, int width, int height, int startFrame,
			int frames);

	Texture xLoadAnimTexture(char* path, int flags, int width, int height,
			int startFrame, int frames);

	void xLoadBuffer(Buffer buffer, char* path);

	Entity xLoadDXmesh(char* path, int opimizeType, Entity parent = NULL);

	Effect xLoadFXFile(char* path);

	Image xLoadImage(char* path);

	Entity xLoadMeshAsync(char* path, Entity parent = NULL);

	void xLoadMeshInThread(char* path, Entity parent = NULL);

	Entity xLoadMeshWithChild(char* path, Entity parent = NULL);

	PixelShader xLoadPixelShader(char* path, char* entryPoint, int ver = PS_2_0);

	PostEffect xLoadPostEffect(char* path, char* entryPoint, int ver = PS_2_0);

	Sound xLoadSound(char* path);

	VertexShader xLoadVertexShader(char* path, char* entryPoint,
			int ver = VS_2_0);

	void xLoopSound(Entity sound);

	bool xLostDevice();

	Entity xMakeSingleSurface(Entity entity);

	int xMaxClipPlanes();

	float xMeshDepth(Entity entity);

	float xMeshHeight(Entity entity);

	float xMeshWidth(Entity entity);

	bool xMeshesIntersect(Entity entity1, Entity entity2);

	void xMidHandle(Image image);

	int xMouseDown(int key);

	void xFlushMouse();

	int xMouseHit(int key);

	int xMouseX();

	int xMouseXSpeed();

	int xMouseY();

	int xMouseYSpeed();

	int xMouseZ();

	int xMouseZSpeed();

	void xMoveMouse(int x, int y);

	void xNameEntity(Entity entity, char* name);

	void xOrigin(int x, int y);

	void xPaintEntity(Entity entity, Brush brush);

	void xPaintMesh(Entity entity, Brush brush);

	void xPaintSurface(Surface surface, Brush brush);

	void xPauseChannel(Channel channel);

	Entity xPickedEntity();

	float xPickedNX();

	float xPickedNY();

	float xPickedNZ();

	Surface xPickedSurface();

	int xPickedTime();

	int xPickedTriangle();

	float xPickedX();

	float xPickedY();

	float xPickedZ();

	Channel xPlayMusic(char* path);

	Channel xPlaySound(Sound sound);

	void xPositionMesh(Entity entity, float x, float y, float z);

	void xPositionTexture(Texture texture, float u, float v);

	float xProjectedX();

	float xProjectedY();

	float xProjectedZ();

	void xPSSMDebugHud(bool mode = false);

	void xPSSMInit(Entity camera, char* path, int mapSize);

	void xPSSMLightRange(float nearRange, float farRange);

	void xPSSMLightSource(float x, float y, float z);

	void xPSSMLightTarget(float x, float y, float z);

	void xPSSMLightZoom(float zoom);

	void xPSSMRender(Entity camera, float splitLambda, int splitPlanes,
			Texture texture);

	void xPSSMSetEntity(Entity entity, bool caster = true, bool receiver = true);

	void xReleaseXors();

	void xRenderPostEffect(Entity entity);

	void xResumeChannel(Channel channel);

	void xRotateImage(Image image, float angle);

	void xRotateMesh(Entity entity, float x, float y, float z);

	void xRotateSprite(Entity entity, float angle);

	void xRotateTexture(Texture texture, float angle);

	void xSaveBuffer(Buffer buffer, char* path);

	void xScaleImage(Image image, float x, float y);

	void xScaleMesh(Entity entity, float x, float y, float z);

	void xScaleSprite(Entity entity, float x, float y);

	void xScaleTexture(Texture texture, float x, float y);

	void xSetAdditionalMatrix(Entity entity, int index, int type);

	void xSetAlphaFunc(Entity entity, int value);

	void xSetAlphaRef(Entity entity, int value);

	void xSetAntiAliasType(int aaType = AA2SAMPLES);

	void xSetBonesArrayName(Entity entity, char* arrayName);

	void xSetBuffer(Buffer buffer);

	void xSetEffectBool(Entity entity, char* name, bool value);

	void xSurfaceEffectBool(Surface surface, char* name, bool value);

	void xSetEffectEntityMatrix(Entity entity, char* name, void* matrix);

	void xSurfaceEffectEntityMatrix(Surface surface, char* name, void* matrix);

	void xSetEffectFloat(Entity entity, char* name, float value);

	void xSurfaceEffectFloat(Surface surface, char* name, float value);

	void xSetEffectFloatArray(Entity entity, char* name, float* value, int size);

	void xSurfaceEffectFloatArray(Surface surface, char* name, float* value,
			int size);

	void xSetEffectInt(Entity entity, char* name, int value);

	void xSurfaceEffectInt(Surface surface, char* name, int value);

	void xSetEffectIntArray(Entity entity, char* name, int* value, int size);

	void xSurfaceEffectIntArray(Surface surface, char* name, int* value,
			int size);

	void xSetEffectMatrix(Entity entity, char* name, float f11, float f12,
			float f13, float f14, float f21, float f22, float f23, float f24,
			float f31, float f32, float f33, float f34, float f41, float f42,
			float f43, float f44);

	void xSurfaceEffectMatrix(Surface surface, char* name, float f11,
			float f12, float f13, float f14, float f21, float f22, float f23,
			float f24, float f31, float f32, float f33, float f34, float f41,
			float f42, float f43, float f44);

	void xSetEffectMatrixArray(Entity entity, char* name, void* value, int size);

	void xSurfaceEffectMatrixArray(Surface surface, char* name, void* value,
			int size);

	void xSetEffectMatrixSemantic(Entity entity, char* name, int semantic);

	void xSurfaceEffectMatrixSemantic(Surface surface, char* name, int semantic);

	void xSetEffectTechnique(Entity entity, char* name);

	void xSurfaceTechnique(Surface surface, char* name);

	void xSetEffectVectorArray(Entity entity, char* name, void* value, int size);

	void xSurfaceEffectVectorArray(Surface surface, char* name, void* value,
			int size);

	void xSetEntityEffect(Entity entity, Effect effect);

	void xSetEntityMatrix(Entity entity, void* matrix);

	void xSetEntityMatrixElement(Entity entity, int row, int cell, float value);

	void xSetEntityPixelShader(Entity entity, PixelShader shader);

	void xSetEntityVertexShader(Entity entity, VertexShader shader);

	void xSetEntityQuaternion(Entity entity, void* quat);

	void xSetFont(Font font);

	void xSetFrustrumSphere(Entity entity, float x, float y, float z,
			float radius);

	void xSetMeshVNIB(Entity entity, float* nVB, float* nNB, int* nIB,
			int* nPIB, int numVert, int numTris);

	void xSetNeedUpdateBoundingSphere(Entity entity, bool need = true);

	void xSetPixelShaderBool(Entity entity, char* name, bool value);

	void xSetPixelShaderDefaults(PixelShader shader);

	void xSetPixelShaderFloat(Entity entity, char* name, float value);

	void xSetPixelShaderInt(Entity entity, char* name, int value);

	void xSetPixelShaderMatrix(Entity entity, char* name, float f11, float f12,
			float f13, float f14, float f21, float f22, float f23, float f24,
			float f31, float f32, float f33, float f34, float f41, float f42,
			float f43, float f44);

	void xSetPixelShaderMatrixSemantic(Entity entity, char* name, int semantic);

	void xSetPostEffectBaseSampler(PostEffect postEffect, char* name);

	void xSetPostEffectBaseSamplerScale(PostEffect postEffect, float x, float y);

	void xSetPostEffectBool(PostEffect postEffect, char* name, bool value);

	void xSetPostEffectDefaults(PostEffect postEffect);

	void xSetPostEffectFloat(PostEffect postEffect, char* name, float value);

	void xSetPostEffectInt(PostEffect postEffect, char* name, int value);

	void xSetPostEffectSceneSampler(PostEffect postEffect, char* sampler);

	void xSetPostEffectTexture(PostEffect postEffect, char* name, Texture value);

	void xSetRenderWindow(void* newWND);

	void xSetTextureFiltering(int filter = TF_LINEAR);

	void xSetTextureFilter(Texture* texture, int mode = -1);

	void xSetVertexShaderBool(Entity entity, char* name, bool value);

	void xSetVertexShaderDefaults(VertexShader shader);

	void xSetVertexShaderFloat(Entity entity, char* name, float value);

	void xSetVertexShaderInt(Entity entity, char* name, int value);

	void xSetVertexShaderMatrix(Entity entity, char* name, float f11,
			float f12, float f13, float f14, float f21, float f22, float f23,
			float f24, float f31, float f32, float f33, float f34, float f41,
			float f42, float f43, float f44);

	void xSetVertexShaderMatrixSemantic(Entity entity, char* name, int semantic);

	void xSetWND(void* hwnd);

	void xShowEntity(Entity entity);

	void xShowPointer();

	void xSoundPan(Sound sound, float pan);

	void xSoundPitch(Sound sound, int hertz);

	void xSoundVolume(Sound sound, float volume);

	bool xSphereInFrustum(Entity camera, float x, float y, float z,
			float radius);

	void xSpriteViewMode(Entity entity, int mode);

	void xStopChannel(Channel channel);

	void xStretchBackBuffer(Texture texture, int x, int y, int width,
			int height, int filter = 0);

	void xStretchRect(Texture texture1, int x1, int y1, int width1,
			int height1, Texture texture2, int x2, int y2, int width2,
			int height2, int filter = 0);

	int xStringHeight(char* text);

	int xStringWidth(char* text);

	void xTFormNormal(float x, float y, float z, Entity src, Entity dest);

	void xTFormPoint(float x, float y, float z, Entity src, Entity dest);

	void xTFormVector(float x, float y, float z, Entity src, Entity dest);

	float xTFormedX();

	float xTFormedY();

	float xTFormedZ();

	float xTerrainHeight(Entity entity, int x, int y);

	void xTerrainShading(Entity entity, bool state);

	int xTerrainSizeX(Entity entity);

	int xTerrainSizeZ(Entity entity);

	float xTerrainX(Entity entity, float x, float y, float z);

	float xTerrainY(Entity entity, float x, float y, float z);

	float xTerrainZ(Entity entity, float x, float y, float z);

	void xTextureBlend(Texture texture, int blend = TEXBLEND_NONE);

	void xTextureCoords(Texture texture, int coords);

	int xTextureHeight(Texture texture);

	char* xTextureName(Texture texture);

	int xTextureWidth(Texture texture);

	int xTriangleVertex(Surface surface, int index, int coner);

	int xTrisRendered();

	void xUpdateIM();

	void xUpdateMeshIB(Entity entity, int* indexArray);

	void xUpdateMeshVBNormals(Entity entity, float* normArray);

	void xUpdateMeshVBPositions(Entity entity, float* posArray);

	void xUpdateNormals(Entity entity);

	void xUpdatePhysxPose(Entity entity);

	bool xValidateEffectTechnique(Effect effect, char* name);

	float xVectorPitch(float x, float y, float z);

	float xVectorYaw(float x, float y, float z);

	float xVertexAlpha(Surface surface, int vertex);

	float xVertexBlue(Surface surface, int vertex);

	void xVertexCoords(Surface surface, int vertex, float x, float y, float z);

	float xVertexGreen(Surface surface, int vertex);

	float xVertexNX(Surface surface, int vertex);

	float xVertexNY(Surface surface, int vertex);

	float xVertexNZ(Surface surface, int vertex);

	void xVertexNormal(Surface surface, int vertex, float nx, float ny,
			float nz);

	float xVertexRed(Surface surface, int vertex);

	float xVertexX(Surface surface, int vertex);

	float xVertexY(Surface surface, int vertex);

	float xVertexZ(Surface surface, int vertex);

	char* xVideoInfo();

	void xWaitKey();

	int xWinMessage(char* msgWin);

	void xWireframe(bool state);

	int xAddVertex(Surface surface, float x, float y, float z, float u,
			float v, float w);

	void xAlignToVector(Entity entity, float x, float y, float z, int axis,
			float factor);

	float xAnimLength(Entity entity, char* rootBone = "");

	int xAnimSeq(Entity entity, char* rootBone = "");

	float xAnimSpeed(Entity entity, char* rootBone = "");

	float xAnimTime(Entity entity, char* rootBone = "");

	void xAnimate(Entity entity, int mode = ANIMATION_STOP, float speed = 1.0f,
			int sequence = 0, float translate = 0.0, char* rootBone = "");

	int xAnimating(Entity entity, char* rootBone = "");

	void xBrushAlpha(Brush brush, float alpha);

	void xBrushBlend(Brush brush, int blend = BLEND_ALPHA);

	void xBrushColor(Brush brush, float red, float green, float blue);

	void xBrushFX(Brush brush, int fxFlags = FX_NOTHING);

	void xBrushShininess(Brush brush, float shininess);

	void xBrushTexture(Brush brush, Texture texture, int frame = 0,
			int index = 0);

	void xCameraFogMode(Entity camera, int fogMode = FOG_NONE);

	void xCameraProjMode(Entity camera, int projMode = PROJ_PERSPECTIVE);

	void xClearSurface(Surface surface, bool clearVertices = true,
			bool clearTrianlges = true);

	void xClearWorld(bool clearEntities = true, bool clearBrushes = true,
			bool clearTexture = true);

	Entity xCopyEntity(Entity entity, Entity parent = NULL,
			bool cloneBuff = false);

	Entity xCopyMesh(Entity entity, Entity parent = NULL);

	void xCopyPixel(int sx, int sy, Buffer src, int dx, int dy, Buffer dest);

	void xCopyPixelFast(int sx, int sy, Buffer src, int dx, int dy, Buffer dest);

	Brush xCreateBrush(float red = 255, float green = 255, float blue = 255);

	Entity xCreateCamera(Entity parent = NULL);

	Entity xCreateCone(int segments, bool solid = true, Entity parent = NULL);

	Entity xCreateCube(Entity parent = NULL);

	Entity xCreateCylinder(int segments, bool solid = true,
			Entity parent = NULL);

	Image xCreateImage(int width, int height, int frame = 1);

	Entity xCreateLight(int lType = LIGHT_DIRECTIONAL);

	Entity xCreateListener(Entity parent = NULL, float rolloffFactor = 1.0f,
			float dopplerScale = 1.0f, float distanceScale = 1.0f);

	Entity xCreateMesh(Entity parent = NULL);

	Entity xCreatePivot(Entity parent = NULL);

	Entity xCreateSphere(int segments, Entity parent = NULL);

	Entity xCreateSprite(Entity parent = NULL);

	Surface xCreateSurface(Entity entity, Brush brush = NULL,
			bool dynamic = false);

	Entity xCreateTerrain(int size, Entity parent = NULL);

	Texture xCreateTexture(int width, int height,
			int flags = FLAGS_COLOR | FLAGS_MIPMAPPED, int frames = 1);

	void xDrawImage(Image image, int x, int y, int frame = 0);

	void xDrawImageRect(Image image, int x, int y, int rx, int ry, int width,
			int height, int frame = 0);

	void xEntityParent(Entity entity, Entity parent = NULL,
			bool isGlobal = false);

	void xEntityPickMode(Entity entity, int mode = PICK_NONE, bool obsc = false);

	float xEntityPitch(Entity entity, bool isGlobal = false);

	float xEntityRoll(Entity entity, bool isGlobal = false);

	void xEntityShininess(Entity entity, float shininess);

	void xEntityTexture(Entity entity, Texture texture, int frame = 0,
			int index = 0);

	int xEntityRed(Entity entity);

	int xEntityGreen(Entity entity);

	int xEntityBlue(Entity entity);

	float xGetEntityShininess(Entity entity);

	int xGetEntityBlend(Entity entity);

	int xGetEntityFX(Entity entity);

	float xEntityX(Entity entity, bool isGlobal = false);

	float xEntityY(Entity entity, bool isGlobal = false);

	float xEntityYaw(Entity entity, bool isGlobal = false);

	float xEntityZ(Entity entity, bool isGlobal = false);

	int xExtractAnimSeq(Entity enity, int firstFrame, int lastFrame,
			int sequence = 0);

	Texture xGetBrushTexture(Brush brush, int index = 0);

	bool xGraphics3D(int width = 640, int height = 480, int depth = 16,
			bool fullScreen = false, bool vsync = false);

	Buffer xImageBuffer(Image image, int frame = 0);

	Entity xLinePick(float x, float y, float z, float dx, float dy, float dz,
			float distance = 0.0f);

	Entity xLoadAnimMesh(char* path, Entity parent = NULL);

	int xLoadAnimSeq(Entity entity, char* path);

	Brush xLoadBrush(char* path, int flags = FLAGS_COLOR | FLAGS_MIPMAPPED,
			float xs = 1.0f, float ys = 1.0f);

	Font xLoadFont(char* path, int height, bool bold = false,
			bool italic = false, bool underline = false);

	Entity xLoadMesh(char* path, Entity parent = NULL);

	Entity xLoadSprite(char* path, int flags = FLAGS_COLOR | FLAGS_MIPMAPPED,
			Entity parent = NULL);

	Entity xLoadTerrain(char* path, Entity parent = NULL);

	Texture xLoadTexture(char* path, int flag = FLAGS_COLOR | FLAGS_MIPMAPPED);

	void xLockBuffer(Buffer buffer = -1);

	void xModifyTerrain(Entity entity, int x, int y, float height,
			bool realTime = false);

	void xMoveEntity(Entity entity, float x, float y, float z,
			bool isGlobal = false);

	void xOval(int x, int y, int width, int height, bool solid = false);

	void xPointEntity(Entity entity1, Entity entity2, float roll = 0.0f);

	void xPositionEntity(Entity entity, float x, float y, float z,
			bool isGlobal = false);

	int xReadPixel(int x, int y, Buffer buffer = -1);

	int xReadPixelFast(int x, int y, Buffer buffer = -1);

	void xRect(int x, int y, int width, int height, bool solid = false);

	void xRenderWorld(float twen = 1.0f);

	void xRenderEntity(Camera camera, Entity entity);

	void xRotateEntity(Entity entity, float x, float y, float z,
			bool isGlobal = false);

	void xSaveImage(Image image, char* path, int frame = 0);

	void xScaleEntity(Entity entity, float x, float y, float z,
			bool isGlobal = false);

	void xSetAnimSpeed(Entity entity, float speed, char* rootBone = "");

	void xSetAnimTime(Entity entity, float time, char* rootBone = "");

	void xSetCubeFace(Texture texture, int face = FACE_FORWARD);

	void xSetEffectTexture(Entity entity, char* name, Texture texture,
			int frame = 0);

	void xSurfaceEffectTexture(Surface surface, char* name, Texture texture,
			int frame = 0);

	void xSetEffectVector(Entity entity, char* name, float x, float y, float z,
			float w = 1.0f);

	void xSurfaceEffectVector(Surface surface, char* name, float x, float y,
			float z, float w = 1.0f);

	void xSetPixelShaderEntityTexture(Entity entity, char* name, int index = 0);

	void xSetEffectEntityTexture(Entity entity, char* name, int index = 0);

	void xSurfaceEffectEntityTexture(Surface surface, char* name, int index = 0);

	void xSetPixelShaderTexture(Entity entity, char* name, Texture texture,
			int frame = 0);

	void xSetPixelShaderVector(Entity entity, char* name, float x, float y,
			float z, float w);

	void xSetPostEffect(PostEffect postEffect, int index = 0);

	void xSetPostEffectVector(PostEffect postEffect, char* name, float x,
			float y, float z, float w);

	void xSetSkinningMethod(int method = SKIN_SOFTWARE);

	void xSetVertexShaderVector(Entity entity, char* name, float x, float y,
			float z, float w);

	void xText(int x, int y, char* text, bool centerx = false,
			bool centery = false);

	Buffer xTextureBuffer(Texture texture, int frame = 0);

	void xTileImage(Image image, int x, int y, int frame = 0);

	void xTranslateEntity(Entity entity, float x, float y, float z,
			bool isGlobal = false);

	void xTurnEntity(Entity entity, float x, float y, float z,
			bool isGlobal = false);

	void xUnlockBuffer(Buffer buffer = -1);

	void xUpdateWorld(float speed = 1.0f);

	void xVertexColor(Surface surface, int vertex, int red, int green,
			int blue, float alpha = 1.0f);

	void xVertexTexCoords(Surface surface, int vertex, float u, float v,
			float w = 1.0f, int coodSet = 0);

	float xVertexU(Surface surface, int vertex, int coodSet = 0);

	float xVertexV(Surface surface, int vertex, int coodSet = 0);

	float xVertexW(Surface surface, int vertex, int coodSet = 0);

	void xWritePixel(int x, int y, int argb, Buffer buffer = -1);

	void xWritePixelFast(int x, int y, int argb, Buffer buffer = -1);

	void xSetSurfaceEffect(Surface surface, Effect effect);

	void xSurfaceBonesArrayName(Surface surface, char* baName);

	PSystem xCreatePSystem(bool pointSprites = false);

	bool xPSystemType(PSystem psystem);

	void xPSystemSetBlend(PSystem psystem, int mode);

	int xPSystemGetBlend(PSystem psystem);

	void xPSystemSetMaxParticles(PSystem psystem, int maxNumber);

	int xPSystemGetMaxParticles(PSystem psystem);

	void xPSystemSetEmitterLifetime(PSystem psystem, int lifetime);

	int xPSystemGetEmitterLifetime(PSystem psystem);

	void xPSystemSetParticleLifetime(PSystem psystem, int lifetime);

	int xPSystemGetParticleLifetime(PSystem psystem);

	void xPSystemSetCreationInterval(PSystem psystem, int interval);

	int xPSystemGetCreationInterval(PSystem psystem);

	void xPSystemSetCreationFrequency(PSystem psystem, int frequency);

	int xPSystemGetCreationFrequency(PSystem psystem);

	void xPSystemSetTexture(PSystem psystem, Texture texture, int frames = 1,
			float speed = 0.0f);

	Texture* xPSystemGetTexture(PSystem psystem);

	int xPSystemGetTextureFrames(PSystem psystem);

	int xPSystemGetTextureAnimationSpeed(PSystem psystem);

	void xPSystemSetOffset(PSystem psystem, float minx, float miny, float minz,
			float maxx, float maxy, float maxz);

	float xPSystemGetOffsetMinX(PSystem psystem);

	float xPSystemGetOffsetMinY(PSystem psystem);

	float xPSystemGetOffsetMinZ(PSystem psystem);

	float xPSystemGetOffsetMaxX(PSystem psystem);

	float xPSystemGetOffsetMaxY(PSystem psystem);

	float xPSystemGetOffsetMaxZ(PSystem psystem);

	void xPSystemSetVelocity(PSystem psystem, float minx, float miny,
			float minz, float maxx, float maxy, float maxz);

	float xPSystemGetVelocityMinX(PSystem psystem);

	float xPSystemGetVelocityMinY(PSystem psystem);

	float xPSystemGetVelocityMinZ(PSystem psystem);

	float xPSystemGetVelocityMaxX(PSystem psystem);

	float xPSystemGetVelocityMaxY(PSystem psystem);

	float xPSystemGetVelocityMaxZ(PSystem psystem);

	void xPSystemEnableFixedQuads(PSystem psystem, bool state);

	bool xPSystemFixedQuadsUsed(PSystem psystem);

	void xPSystemSetTorque(PSystem psystem, float minx, float miny, float minz,
			float maxx, float maxy, float maxz);

	float xPSystemGetTorqueMinX(PSystem psystem);

	float xPSystemGetTorqueMinY(PSystem psystem);

	float xPSystemGetTorqueMinZ(PSystem psystem);

	float xPSystemGetTorqueMaxX(PSystem psystem);

	float xPSystemGetTorqueMaxY(PSystem psystem);

	float xPSystemGetTorqueMaxZ(PSystem psystem);

	void xPSystemSetGravity(PSystem psystem, float gravity);

	float xPSystemGetGravity(PSystem psystem);

	void xPSystemSetAlpha(PSystem psystem, float alpha);

	float xPSystemGetAlpha(PSystem psystem);

	void xPSystemSetFadeSpeed(PSystem psystem, float speed);

	float xPSystemGetFadeSpeed(PSystem psystem);

	void xPSystemSetParticleSize(PSystem psystem, float minx, float miny,
			float maxx, float maxy);

	float xPSystemGetSizeMinX(PSystem psystem);

	float xPSystemGetSizeMinY(PSystem psystem);

	float xPSystemGetSizeMaxX(PSystem psystem);

	float xPSystemGetSizeMaxY(PSystem psystem);

	void xPSystemSetScaleSpeed(PSystem psystem, float minx, float miny,
			float maxx, float maxy);

	float xPSystemGetScaleSpeedMinX(PSystem psystem);

	float xPSystemGetScaleSpeedMinY(PSystem psystem);

	float xPSystemGetScaleSpeedMaxX(PSystem psystem);

	float xPSystemGetScaleSpeedMaxY(PSystem psystem);

	void xPSystemSetAngles(PSystem psystem, float minx, float miny, float minz,
			float maxx, float maxy, float maxz);

	float xPSystemGetAnglesMinX(PSystem psystem);

	float xPSystemGetAnglesMinY(PSystem psystem);

	float xPSystemGetAnglesMinZ(PSystem psystem);

	float xPSystemGetAnglesMaxX(PSystem psystem);

	float xPSystemGetAnglesMaxY(PSystem psystem);

	float xPSystemGetAnglesMaxZ(PSystem psystem);

	void xPSystemSetColorMode(PSystem psystem, int mode);

	int xPSystemGetColorMode(PSystem psystem);

	void xPSystemSetColors(PSystem psystem, float sred, float sgreen,
			float sblue, float ered, float egreen, float eblue);

	float xPSystemGetBeginColorRed(PSystem psystem);

	float xPSystemGetBeginColorGreen(PSystem psystem);

	float xPSystemGetBeginColorBlue(PSystem psystem);

	float xPSystemGetEndColorRed(PSystem psystem);

	float xPSystemGetEndColorGreen(PSystem psystem);

	float xPSystemGetEndColorBlue(PSystem psystem);

	void xFreePSystem(PSystem psystem);

	Entity xCreateEmitter(PSystem psystem, Entity parent = NULL);

	void xEmitterEnable(Entity emitter, bool state);

	bool xEmitterEnabled(Entity emitter);

	PSystem xEmitterGetPSystem(Entity emitter);

	int xEmitterAddParticle(Entity emitter);

	void xEmitterFreeParticle(Entity emitter, int particle);

	bool xEmitterValidateParticle(Entity emitter, int particle);

	int xEmitterCountParticles(Entity emitter);

	int xEmitterGetParticle(Entity emitter, int index);

	void xParticlePosition(int particle, float x, float y, float z);

	float xParticleX(int particle);

	float xParticleY(int particle);

	float xParticleZ(int particle);

	void xParticleVeclocity(int particle, float x, float y, float z);

	float xParticleVX(int particle);

	float xParticleVY(int particle);

	float xParticleVZ(int particle);

	void xParticleRotation(int particle, float x, float y, float z);

	float xParticlePitch(int particle);

	float xParticleYaw(int particle);

	float xParticleRoll(int particle);

	void xParticleTorque(int particle, float x, float y, float z);

	float xParticleTPitch(int particle);

	float xParticleTYaw(int particle);

	float xParticleTRoll(int particle);

	void xParticleSetAlpha(int particle, float alpha);

	float xParticleGetAlpha(int particle);

	void xParticleColor(int particle, float x, float y, float z);

	float xParticleRed(int particle);

	float xParticleGreen(int particle);

	float xParticleBlue(int particle);

	void xParticleScale(int particle, float x, float y);

	float xParticleSX(int particle);

	float xParticleSY(int particle);

	void xParticleScaleSpeed(int particle, float x, float y);

	float xParticleScaleSpeedX(int particle);

	float xParticleScaleSpeedY(int particle);
}